@extends('admin.layouts.app')

{{-- Custom CSS --}}
@section('custom-css')
    <style>
        #loader {
            display: flex;
            text-align: center;
            justify-content: center;
        }
        .btn-sm {
            font-size: 0.75rem !important;
        }
    </style>
@endsection

@section('content')
    <div class="page-wrapper">
        <div class="container-xl">
            <!-- Page title -->
            <div class="page-header d-print-none">
                <div class="row align-items-center">
                    <div class="col">
                        <div class="page-pretitle">
                            {{ __('Overview') }}
                        </div>
                        <h2 class="page-title">
                            {{ __('Bulk Upload') }}
                        </h2>
                    </div>
                </div>
            </div>
        </div>
        <div class="page-body">
            <div class="container-xl">

                {{-- Failed --}}
                @if (Session::has('failed'))
                    <div class="alert alert-important alert-danger alert-dismissible" role="alert">
                        <div class="d-flex">
                            <div>
                                {{ Session::get('failed') }}
                            </div>
                        </div>
                        <a class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="close"></a>
                    </div>
                @endif

                {{-- Success --}}
                @if (Session::has('success'))
                    <div class="alert alert-important alert-success alert-dismissible" role="alert">
                        <div class="d-flex">
                            <div>
                                {{ Session::get('success') }}
                            </div>
                        </div>
                        <a class="btn-close btn-close-white" data-bs-dismiss="alert" aria-label="close"></a>
                    </div>
                @endif

                <div class="row row-cards">
                    <div class="col-sm-12 col-lg-12">
                        <form action="{{ route('admin.import.bulk.upload') }}" method="post" enctype="multipart/form-data">
                            @csrf
                            <div class="card">
                                <div class="card-body">
                                    <div class="row">
                                        {{-- Groups --}}
                                        <div class="col-md-6 col-xl-6">
                                            <div class="mb-3">
                                                <label class="form-label required">{{ __('Group') }}</label>
                                                <select type="text" name="group" class="form-select" id="select-groups"
                                                    value="" required>
                                                    <option value="" selected disabled>{{ __('Choose group') }}
                                                    </option>
                                                    {{-- Groups --}}
                                                    @foreach ($groups as $group)
                                                        <option value="{{ $group->group_id }}">
                                                            {{ __($group->group_name) }}</option>
                                                    @endforeach
                                                </select>
                                            </div>
                                        </div>

                                        {{-- File upload --}}
                                        <div class="col-md-6 col-xl-6">
                                            <div class="mb-3">
                                                <div class="form-label required">{{ __('Choose a file')}}</div>
                                                <input type="file" name="file" class="form-control" accept=".xlsx,.xls" required />
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <div class="card-footer text-end">
                                    <div class="d-flex">
                                        <a href="{{ asset('instructions.xlsx') }}" download="" class="btn btn-secondary btn-sm">
                                            {{ __('Instruction') }}
                                        </a>
                                        <a href="{{ asset('sample-bulk-file.xlsx') }}" download="" class="btn btn-secondary btn-sm mx-2">
                                            {{ __('Sample xlsx file') }}
                                        </a>
                                        <button type="submit" class="btn btn-primary ms-auto">
                                            {{ __('Submit') }}
                                        </button>
                                    </div>
                                </div>
                            </div>
                        </form>
                    </div>
                </div>
            </div>
        </div>

        {{-- Footer --}}
        @include('admin.includes.footer')
    </div>

    {{-- Custom JS --}}
@section('custom-js')
    <script src="{{ asset('js/tom-select.base.min.js') }}"></script>
    <script>
        // @formatter:off
        document.addEventListener("DOMContentLoaded", function() {
            var el;
            window.TomSelect && (new TomSelect(el = document.getElementById('select-groups'), {
                copyClassesToDropdown: false,
                dropdownParent: 'body',
                controlInput: '<input>',
                render: {
                    item: function(data, escape) {
                        if (data.customProperties) {
                            return '<div><span class="dropdown-item-indicator">' + data
                                .customProperties + '</span>' + escape(data.text) + '</div>';
                        }
                        return '<div>' + escape(data.text) + '</div>';
                    },
                    option: function(data, escape) {
                        if (data.customProperties) {
                            return '<div><span class="dropdown-item-indicator">' + data
                                .customProperties + '</span>' + escape(data.text) + '</div>';
                        }
                        return '<div>' + escape(data.text) + '</div>';
                    },
                },
            }));
        });
        // @formatter:on
    </script>
@endsection
@endsection
